@@ -3,7 +3,7 @@ package CPAN::Plugin::Sysdeps::Mapping;
 use strict;
 use warnings;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 # shortcuts
 #  os and distros
@@ -80,6 +80,11 @@ sub mapping {
        [package => [qw(gtk2-devel cairo-devel libX11-devel libGLU-devel freeglut-devel)]]],
      ],
 
+     [cpanmod => 'Alien::LibJIT',
+      [like_debian,
+       [package => [qw(autoconf libtool flex bison texinfo)]]], # but no success building it
+     ],
+
      [cpanmod => 'Alien::LibUSBx',
       # XXX what about freebsd?
       [like_debian,
@@ -223,6 +228,15 @@ sub mapping {
       # no package for Debian & CentOS7
      ],
 
+     [cpanmod => 'Audio::CD',
+      [os_freebsd,
+       [package => 'libcdaudio']],
+      [like_debian,
+       [package => 'libcdaudio-dev']],
+      [like_fedora,
+       [package => 'libcdaudio-devel']],
+     ],
+
      [cpanmod => 'Audio::Extract::PCM',
       # but does not work with freebsd, see https://bugs.freebsd.org/bugzilla/show_bug.cgi?id=205732
       [package => 'sox']],
@@ -456,6 +470,15 @@ sub mapping {
        [package => 'augeas']],
      ],
 
+     [cpanmod => 'Convert::Recode',
+      [os_freebsd,
+       [package => 'recode']],
+      [like_debian,
+       [package => 'recode']],
+      [like_fedora,
+       [package => 'recode']],
+     ],
+
      [cpanmod => 'Crypt::Cracklib',
       [os_freebsd,
        [package => 'cracklib']],
@@ -745,6 +768,11 @@ sub mapping {
       # no package for Debian (jessie, stretch) and CentOS7
      ],
 
+     [cpanmod => 'Erlang::Interface',
+      [like_debian,
+       [package => 'erlang-dev']],
+     ],
+
      [cpanmod => 'EV::ADNS',
       [os_freebsd,
        [package => 'adns']],
@@ -1007,6 +1035,11 @@ sub mapping {
       [like_debian,
        [package => 'libgnomevfs2-dev']]],
 
+     [cpanmod => 'Gnome::Sound',
+      [like_debian,
+       [package => 'libgnome2-dev']], # does not work, module does not look into /usr/include/libgnome-2.0/
+     ],
+
      [cpanmod => 'GnuPG::Interface',
       [os_freebsd,
        [package => 'gnupg1'] #  XXX what about gnupg (version 2)?
@@ -1073,6 +1106,12 @@ sub mapping {
        [package => 'gtk2-devel']],
      ],
 
+     [cpanmod => 'Gtk2::AppIndicator',
+      # no package for freebsd or centos7
+      [like_debian,
+       [package => 'libappindicator-dev']],
+     ],
+
      [cpanmod => 'Gtk2::GladeXML',
       [os_freebsd,
        [package => 'libglade2']],
@@ -1186,6 +1225,15 @@ sub mapping {
       # ctpp2 not available for homebrew
      ],
 
+     [cpanmod => 'HTTP::Webdav',
+      [os_freebsd,
+       [package => 'neon | neon29']], # untested
+      [like_debian,
+       [package => 'libneon27-dev | ibneon27-gnutls-dev']], # compilation fails: ne_cookies.h: No such file or directory
+      [like_fedora,
+       [package => 'neon-devel']], # compilation fails: ne_cookies.h: No such file or directory
+     ],
+
      [cpanmod => 'HTML::Tidy',
       [os_freebsd,
        [package => 'tidyp']],
@@ -1290,6 +1338,15 @@ sub mapping {
       [like_debian,
        [package => ['libmagick++-dev | graphicsmagick-libmagick-dev-compat']]]],
 
+     [cpanmod => 'Image::XFace', # compiles only for old perls
+      [os_freebsd,
+       [package => 'faces']],
+      [like_debian,
+       [package => 'libcompfaceg1-dev']],
+      [like_fedora,
+       [package => 'compface-devel']],
+     ],
+
      [cpanmod => 'Imager',
       [os_freebsd,
        [package => [qw(freetype2 giflib png tiff), freebsd_jpeg]]], # in former days giflib-nox11 had to be specified
@@ -1364,6 +1421,15 @@ sub mapping {
        [package => 'ruby-devel']],
      ],
 
+     [cpanmod => 'Inline::SLang',
+      [os_freebsd,
+       [package => 'libslang2']], # build error
+      [like_debian,
+       [package => 'libslang2-dev']], # module cannot detect lib location
+      [like_fedora,
+       [package => 'slang-devel']], # module cannot detect lib location
+     ],
+
      [cpanmod => 'IPC::MMA',
       [os_freebsd,
        [package => 'mm']],
@@ -1407,9 +1473,6 @@ sub mapping {
        [package => 'jq']],
      ],
 
-#	# for some Judy-using modules (XXX which one?)
-#	package { "Judy": ensure => installed } # XXX this is freebsd; what about debian?
-
      [cpanmod => 'Kafka::Librd',
       # no package for freebsd
       [like_debian,
@@ -1595,6 +1658,19 @@ sub mapping {
       # XXX what about debian?
      ],
 
+     [cpanmod => 'Math::ThinPlateSpline',
+      [os_freebsd,
+       [package => 'boost-libs']], # untested
+      [like_debian,
+       [linuxdistrocodename => 'jessie',
+	[package => 'libboost1.55-dev']],
+       [linuxdistrocodename => 'xenial',
+	[package => 'libboost1.58-dev']],
+       [linuxdistrocodename => 'stretch',
+	[package => 'libboost1.62-dev']],
+      ],
+     ],
+
      [cpanmod => 'MaxMind::DB::Reader::XS',
       [os_freebsd,
        [package => 'libmaxminddb']],
@@ -1636,6 +1712,13 @@ sub mapping {
 	[package => 'apache2-prefork-dev']],
        [package => 'apache2-dev']]],
 
+     [cpanmod => 'MusicBrainz::DiscID',
+      [os_freebsd,
+       [package => 'libdiscid']],
+      [like_debian,
+       [package => 'libdiscid-dev']],
+     ],
+
      [cpanmod => 'NanoMsg::Raw',
       [os_freebsd,
        [package => 'nanomsg']],
@@ -1890,7 +1973,10 @@ sub mapping {
 
      [cpanmod => 'PAM',
       [like_debian,
-       [package => 'libpam0g-dev']]],
+       [package => 'libpam0g-dev']],
+      [like_fedora,
+       [package => 'pam-devel']],
+     ],
 
      [cpanmod => 'Pango',
       [os_freebsd,
@@ -2002,6 +2088,13 @@ sub mapping {
        [package => 'pcre2-devel']],
      ],
 
+     [cpanmod => 'Remind::Client', # but does not work: "Remind output didn't look right; got: 2017/04/24 it works! today"
+      [os_freebsd,
+       [package => 'remind']],
+      [like_debian,
+       [package => 'remind']],
+     ],
+
      [cpanmod => 'RPC::Xmlrpc_c::Client',
       [os_freebsd,
        [package => 'xmlrpc-c']],
@@ -2017,6 +2110,12 @@ sub mapping {
 #	## XXX disabled because package was not yet built (last check 2014-08-10)
 #	## see http://portsmon.freebsd.org/portoverview.py?category=archivers&portname=rpm5
 #	#package { "rpm5": ensure => installed }
+     [cpanmod => 'RPM2',
+      [like_debian,
+       [package => 'librpm-dev']], # but tests fail
+      [like_fedora,
+       [package => 'rpm-devel']],
+     ],
 
      [cpanmod => 'RRD::Tweak',
       [os_freebsd,
@@ -2225,6 +2324,15 @@ sub mapping {
      [cpanmod => 'Tie::Cvs',
       [package => 'cvs']],
 
+     [cpanmod => 'Tie::Judy', # but tests fail (hash randomization?)
+      [os_freebsd,
+       [package => 'judy']],
+      [like_debian,
+       [package => 'libjudy-dev']],
+      [like_fedora,
+       [package => 'Judy-devel']],
+     ],
+
      [cpanmod => 'Tree::Suffix',
       [os_freebsd,
        [package => 'libstree']],
